@@ -9,9 +9,9 @@ from .seating_plan import setup_default_plan
 
 def add_permissions_to_builtin_groups(**kwargs):
     """
-    Adds the permissions openslides_votecollector.can_manage_votecollector to the group staff.
+    Adds the permissions openslides_votecollector.can_manage to the group staff.
     """
-    content_type = ContentType.objects.get(app_label='openslides_votecollector', model='keypad')
+    content_type = ContentType.objects.get(app_label='openslides_votecollector', model='votecollector')
 
     try:
         # Group with pk == 3 should be the staff group in OpenSlides 2.1
@@ -19,7 +19,7 @@ def add_permissions_to_builtin_groups(**kwargs):
     except Group.DoesNotExist:
         pass
     else:
-        perm_can_manage = Permission.objects.get(content_type=content_type, codename='can_manage_votecollector')
+        perm_can_manage = Permission.objects.get(content_type=content_type, codename='can_manage')
         staff.permissions.add(perm_can_manage)
 
 
